@@ -1,10 +1,11 @@
-from __future__ import absolute_import, division
-from .auto import tqdm as tqdm_auto
 from copy import copy
 from functools import partial
+
+from .auto import tqdm as tqdm_auto
+
 try:
     import keras
-except ImportError as e:
+except (ImportError, AttributeError) as e:
     try:
         from tensorflow import keras
     except ImportError:
@@ -14,7 +15,7 @@ __all__ = ['TqdmCallback']
 
 
 class TqdmCallback(keras.callbacks.Callback):
-    """`keras` callback for epoch and batch progress"""
+    """Keras callback for epoch and batch progress."""
     @staticmethod
     def bar2callback(bar, pop=None, delta=(lambda logs: 1)):
         def callback(_, logs=None):
@@ -42,7 +43,7 @@ class TqdmCallback(keras.callbacks.Callback):
             0: epoch, 1: batch (transient), 2: batch. [default: 1].
             Will be set to `0` unless both `data_size` and `batch_size`
             are given.
-        tqdm_class : optional
+        tqdm_class  : optional
             `tqdm` class to use for bars [default: `tqdm.auto.tqdm`].
         tqdm_kwargs  : optional
             Any other arguments used for all bars.
@@ -58,20 +59,21 @@ class TqdmCallback(keras.callbacks.Callback):
             self.batches = batches = None
         self.verbose = verbose
         if verbose == 1:
-            self.batch_bar = tqdm_class(total=batches, unit='batch',
-                                        leave=False)
+            self.batch_bar = tqdm_class(total=batches, unit='batch', leave=False)
             self.on_batch_end = self.bar2callback(
-                self.batch_bar,
-                pop=['batch', 'size'],
+                self.batch_bar, pop=['batch', 'size'],
                 delta=lambda logs: logs.get('size', 1))
 
     def on_train_begin(self, *_, **__):
         params = self.params.get
         auto_total = params('epochs', params('nb_epoch', None))
-        if auto_total is not None:
+        if auto_total is not None and auto_total != self.epoch_bar.total:
             self.epoch_bar.reset(total=auto_total)
 
-    def on_epoch_begin(self, *_, **__):
+    def on_epoch_begin(self, epoch, *_, **__):
+        if self.epoch_bar.n < epoch:
+            ebar = self.epoch_bar
+            ebar.n = ebar.last_print_n = ebar.initial = epoch
         if self.verbose:
             params = self.params.get
             total = params('samples', params(
@@ -83,8 +85,7 @@ class TqdmCallback(keras.callbacks.Callback):
                     total=total, unit='batch', leave=True,
                     unit_scale=1 / (params('batch_size', 1) or 1))
                 self.on_batch_end = self.bar2callback(
-                    self.batch_bar,
-                    pop=['batch', 'size'],
+                    self.batch_bar, pop=['batch', 'size'],
                     delta=lambda logs: logs.get('size', 1))
             elif self.verbose == 1:
                 self.batch_bar.unit_scale = 1 / (params('batch_size', 1) or 1)
@@ -98,7 +99,7 @@ class TqdmCallback(keras.callbacks.Callback):
         self.epoch_bar.close()
 
     def display(self):
-        """displays in the current cell in Notebooks"""
+        """Displays in the current cell in Notebooks."""
         container = getattr(self.epoch_bar, 'container', None)
         if container is None:
             return
