@@ -1,131 +1,33 @@
 """
 General helpers required for `tqdm.std`.
 """
-from functools import wraps
-from warnings import warn
 import os
 import re
 import sys
-import subprocess
+from functools import wraps
+# TODO consider using wcswidth third-party package for 0-width characters
+from unicodedata import east_asian_width
+from warnings import warn
+from weakref import proxy
 
+_range, _unich, _unicode, _basestring = range, chr, str, str
 CUR_OS = sys.platform
 IS_WIN = any(CUR_OS.startswith(i) for i in ['win32', 'cygwin'])
 IS_NIX = any(CUR_OS.startswith(i) for i in ['aix', 'linux', 'darwin'])
 RE_ANSI = re.compile(r"\x1b\[[;\d]*[A-Za-z]")
 
-
-# Py2/3 compat. Empty conditional to avoid coverage
-if True:  # pragma: no cover
-    try:
-        _range = xrange
-    except NameError:
-        _range = range
-
-    try:
-        _unich = unichr
-    except NameError:
-        _unich = chr
-
-    try:
-        _unicode = unicode
-    except NameError:
-        _unicode = str
-
-    try:
-        if IS_WIN:
-            import colorama
-        else:
-            raise ImportError
-    except ImportError:
-        colorama = None
+try:
+    if IS_WIN:
+        import colorama
     else:
-        try:
-            colorama.init(strip=False)
-        except TypeError:
-            colorama.init()
-
+        raise ImportError
+except ImportError:
+    colorama = None
+else:
     try:
-        from weakref import WeakSet
-    except ImportError:
-        WeakSet = set
-
-    try:
-        _basestring = basestring
-    except NameError:
-        _basestring = str
-
-    try:  # py>=2.7,>=3.1
-        from collections import OrderedDict as _OrderedDict
-    except ImportError:
-        try:  # older Python versions with backported ordereddict lib
-            from ordereddict import OrderedDict as _OrderedDict
-        except ImportError:  # older Python versions without ordereddict lib
-            # Py2.6,3.0 compat, from PEP 372
-            from collections import MutableMapping
-
-            class _OrderedDict(dict, MutableMapping):
-                # Methods with direct access to underlying attributes
-                def __init__(self, *args, **kwds):
-                    if len(args) > 1:
-                        raise TypeError('expected at 1 argument, got %d',
-                                        len(args))
-                    if not hasattr(self, '_keys'):
-                        self._keys = []
-                    self.update(*args, **kwds)
-
-                def clear(self):
-                    del self._keys[:]
-                    dict.clear(self)
-
-                def __setitem__(self, key, value):
-                    if key not in self:
-                        self._keys.append(key)
-                    dict.__setitem__(self, key, value)
-
-                def __delitem__(self, key):
-                    dict.__delitem__(self, key)
-                    self._keys.remove(key)
-
-                def __iter__(self):
-                    return iter(self._keys)
-
-                def __reversed__(self):
-                    return reversed(self._keys)
-
-                def popitem(self):
-                    if not self:
-                        raise KeyError
-                    key = self._keys.pop()
-                    value = dict.pop(self, key)
-                    return key, value
-
-                def __reduce__(self):
-                    items = [[k, self[k]] for k in self]
-                    inst_dict = vars(self).copy()
-                    inst_dict.pop('_keys', None)
-                    return self.__class__, (items,), inst_dict
-
-                # Methods with indirect access via the above methods
-                setdefault = MutableMapping.setdefault
-                update = MutableMapping.update
-                pop = MutableMapping.pop
-                keys = MutableMapping.keys
-                values = MutableMapping.values
-                items = MutableMapping.items
-
-                def __repr__(self):
-                    pairs = ', '.join(map('%r: %r'.__mod__, self.items()))
-                    return '%s({%s})' % (self.__class__.__name__, pairs)
-
-                def copy(self):
-                    return self.__class__(self)
-
-                @classmethod
-                def fromkeys(cls, iterable, value=None):
-                    d = cls()
-                    for key in iterable:
-                        d[key] = value
-                    return d
+        colorama.init(strip=False)
+    except TypeError:
+        colorama.init()
 
 
 class FormatReplace(object):
@@ -133,7 +35,7 @@ class FormatReplace(object):
     >>> a = FormatReplace('something')
     >>> "{:5d}".format(a)
     'something'
-    """
+    """  # NOQA: P102
     def __init__(self, replace=''):
         self.replace = replace
         self.format_called = 0
@@ -218,27 +120,35 @@ class DisableOnWriteError(ObjectWrapper):
         """
         Quietly set `tqdm_instance.miniters=inf` if `func` raises `errno=5`.
         """
+        tqdm_instance = proxy(tqdm_instance)
+
         def inner(*args, **kwargs):
             try:
                 return func(*args, **kwargs)
-            except (IOError, OSError) as e:
+            except OSError as e:
                 if e.errno != 5:
                     raise
-                tqdm_instance.miniters = float('inf')
+                try:
+                    tqdm_instance.miniters = float('inf')
+                except ReferenceError:
+                    pass
             except ValueError as e:
                 if 'closed' not in str(e):
                     raise
-                tqdm_instance.miniters = float('inf')
+                try:
+                    tqdm_instance.miniters = float('inf')
+                except ReferenceError:
+                    pass
         return inner
 
     def __init__(self, wrapped, tqdm_instance):
         super(DisableOnWriteError, self).__init__(wrapped)
         if hasattr(wrapped, 'write'):
-            self.wrapper_setattr('write', self.disable_on_exception(
-                tqdm_instance, wrapped.write))
+            self.wrapper_setattr(
+                'write', self.disable_on_exception(tqdm_instance, wrapped.write))
         if hasattr(wrapped, 'flush'):
-            self.wrapper_setattr('flush', self.disable_on_exception(
-                tqdm_instance, wrapped.flush))
+            self.wrapper_setattr(
+                'flush', self.disable_on_exception(tqdm_instance, wrapped.flush))
 
     def __eq__(self, other):
         return self._wrapped == getattr(other, '_wrapped', other)
@@ -278,7 +188,7 @@ def _is_utf(encoding):
     except Exception:
         try:
             return encoding.lower().startswith('utf-') or ('U8' == encoding)
-        except:
+        except Exception:
             return False
     else:
         return True
@@ -317,8 +227,8 @@ def _screen_shape_wrapper():  # pragma: no cover
 
 def _screen_shape_windows(fp):  # pragma: no cover
     try:
-        from ctypes import windll, create_string_buffer
         import struct
+        from ctypes import create_string_buffer, windll
         from sys import stdin, stdout
 
         io_handle = -12  # assume stderr
@@ -334,7 +244,7 @@ def _screen_shape_windows(fp):  # pragma: no cover
             (_bufx, _bufy, _curx, _cury, _wattr, left, top, right, bottom,
              _maxx, _maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
             return right - left, bottom - top  # +1
-    except:
+    except Exception:  # nosec
         pass
     return None, None
 
@@ -343,9 +253,10 @@ def _screen_shape_tput(*_):  # pragma: no cover
     """cygwin xterm (windows)"""
     try:
         import shlex
-        return [int(subprocess.check_call(shlex.split('tput ' + i))) - 1
+        from subprocess import check_call  # nosec
+        return [int(check_call(shlex.split('tput ' + i))) - 1
                 for i in ('cols', 'lines')]
-    except:
+    except Exception:  # nosec
         pass
     return None, None
 
@@ -353,19 +264,19 @@ def _screen_shape_tput(*_):  # pragma: no cover
 def _screen_shape_linux(fp):  # pragma: no cover
 
     try:
-        from termios import TIOCGWINSZ
-        from fcntl import ioctl
         from array import array
+        from fcntl import ioctl
+        from termios import TIOCGWINSZ
     except ImportError:
-        return None
+        return None, None
     else:
         try:
             rows, cols = array('h', ioctl(fp, TIOCGWINSZ, '\0' * 8))[:2]
             return cols, rows
-        except:
+        except Exception:
             try:
                 return [int(os.environ[i]) - 1 for i in ("COLUMNS", "LINES")]
-            except KeyError:
+            except (KeyError, ValueError):
                 return None, None
 
 
@@ -391,15 +302,8 @@ def _term_move_up():  # pragma: no cover
     return '' if (os.name == 'nt') and (colorama is None) else '\x1b[A'
 
 
-try:
-    # TODO consider using wcswidth third-party package for 0-width characters
-    from unicodedata import east_asian_width
-except ImportError:
-    _text_width = len
-else:
-    def _text_width(s):
-        return sum(
-            2 if east_asian_width(ch) in 'FW' else 1 for ch in _unicode(s))
+def _text_width(s):
+    return sum(2 if east_asian_width(ch) in 'FW' else 1 for ch in str(s))
 
 
 def disp_len(data):
